aboutsummaryrefslogtreecommitdiff
path: root/src/zenserver/config/config.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/zenserver/config/config.h')
-rw-r--r--src/zenserver/config/config.h46
1 files changed, 25 insertions, 21 deletions
diff --git a/src/zenserver/config/config.h b/src/zenserver/config/config.h
index d35a1a8c7..186b80b6b 100644
--- a/src/zenserver/config/config.h
+++ b/src/zenserver/config/config.h
@@ -4,6 +4,7 @@
#include <zencore/logbase.h>
#include <zencore/trace.h>
+#include <zencore/uid.h>
#include <zencore/zencore.h>
#include <zenhttp/httpserver.h>
#include <zenutil/config/loggingconfig.h>
@@ -50,27 +51,30 @@ struct ZenServerConfig
ZenSentryConfig SentryConfig;
ZenStatsConfig StatsConfig;
ZenLoggingConfig LoggingConfig;
- static constexpr int kDefaultBasePort = 8558;
- int BasePort = 0; // Service listen port; 0 = auto (resolved per mode)
- int OwnerPid = 0; // Parent process id (zero for standalone)
- bool IsDebug = false;
- bool IsCleanStart = false; // Indicates whether all state should be wiped on startup or not
- bool IsPowerCycle = false; // When true, the process shuts down immediately after initialization
- bool IsTest = false;
- bool Detach = true; // Whether zenserver should detach from existing process group (Mac/Linux)
- int CoreLimit = 0; // If set, hardware concurrency queries are capped at this number
- int LieCpu = 0;
- bool IsDedicated = false; // Indicates a dedicated/shared instance, with larger resource requirements
- bool AllowPortProbing = true; // Automatically false if IsDedicated is true
- bool ShouldCrash = false; // Option for testing crash handling
- bool IsFirstRun = false;
- std::filesystem::path ConfigFile; // Path to Lua config file
- std::filesystem::path SystemRootDir; // System root directory (used for machine level config)
- std::filesystem::path ContentDir; // Root directory for serving frontend content (experimental)
- std::filesystem::path DataDir; // Root directory for state (used for testing)
- std::filesystem::path BaseSnapshotDir; // Path to server state snapshot (will be copied into data dir on start)
- std::string ChildId; // Id assigned by parent process (used for lifetime management)
- std::filesystem::path SecurityConfigPath; // Path to a Json security configuration file
+ static constexpr int kDefaultBasePort = 8558;
+ int BasePort = 0; // Service listen port; 0 = auto (resolved per mode)
+ int OwnerPid = 0; // Parent process id (zero for standalone)
+ Oid ParentSessionId = Oid::Zero;
+ bool IsDebug = false;
+ bool IsCleanStart = false; // Indicates whether all state should be wiped on startup or not
+ bool IsPowerCycle = false; // When true, the process shuts down immediately after initialization
+ bool IsTest = false;
+ bool Detach = true; // Whether zenserver should detach from existing process group (Mac/Linux)
+ int CoreLimit = 0; // If set, hardware concurrency queries are capped at this number
+ int LieCpu = 0;
+ bool IsDedicated = false; // Indicates a dedicated/shared instance, with larger resource requirements
+ bool AllowPortProbing = true; // Automatically false if IsDedicated is true
+ bool ShouldCrash = false; // Option for testing crash handling
+ bool IsFirstRun = false;
+ bool UseInProcSessionLogging = true; // When false, session logs are expected to be forwarded externally.
+ std::string SessionsTargetUrl; // URL of remote zenserver to announce session to (overrides ZEN_SESSIONS_URL).
+ std::filesystem::path ConfigFile; // Path to Lua config file
+ std::filesystem::path SystemRootDir; // System root directory (used for machine level config)
+ std::filesystem::path ContentDir; // Root directory for serving frontend content (experimental)
+ std::filesystem::path DataDir; // Root directory for state (used for testing)
+ std::filesystem::path BaseSnapshotDir; // Path to server state snapshot (will be copied into data dir on start)
+ std::string ChildId; // Id assigned by parent process (used for lifetime management)
+ std::filesystem::path SecurityConfigPath; // Path to a Json security configuration file
#if ZEN_WITH_TRACE
bool HasTraceCommandlineOptions = false;